@@ -1,12 +1,26 @@
-import requests, time ,os, socket
+import requests, time ,os, socket, hashlib, sys, datetime
 
 def start():
     hostname = socket.gethostname()
+
+    
+    today = datetime.date.today()
+    node_token = hashlib.md5('miaosla_token{}'.format(str(today.day)).encode('utf-8')).hexdigest()
+
     dataa = {
+            'token': node_token,
             'nodename': "-----\rSystem Message",
-            'log':time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：Start BOT in {}({})".format(hostname,str(get_host_ip()))
+            'log':time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：Start BOT in {}\rLocal IP: {} | Request IP:".format(hostname,str(get_host_ip()))
         }
-    requests.get('https://miao.mw-ai.cn/cloudlog/log.php',params=dataa)
+    get_node = requests.get('https://miao.mw-ai.cn/cloudlog/start.php',params=dataa)
+    if get_node.text == 'ok':
+        print('Central node connection: \033[0;32mSuccess\033[0m')
+    elif get_node.text == 'error':
+        print('Central node connection: \033[0;31mError\033[0m')
+        sys.exit()
+    else:
+        print('Central node connection: {}'.format(get_node.text))
+        sys.exit()
 
 def get_host_ip():
     try:
@@ -27,25 +41,60 @@ def sleep(time_d):
 
 def sla(url, status, node_name, bot_token, chat_id):
 
-    def cloudlog(node_name_a, error_num_a):
-        dataa = {
-            'nodename': node_name_a,
-            'log':time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：{}".format(str(error_num_a))
-        }
-        requests.get('https://miao.mw-ai.cn/cloudlog/log.php',params=dataa)
+    def cloudlog(node_name_a, error_num_a, url_a):
+        try:
+            today = datetime.date.today()
+            node_token = hashlib.md5('miaosla_token{}'.format(str(today.day)).encode('utf-8')).hexdigest()
+            dataa = {
+                'token': node_token,
+                'nodename': node_name_a,
+                'log':time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：{}".format(str(error_num_a))
+            }
+            get_node = requests.get('https://miao.mw-ai.cn/cloudlog/log.php',params=dataa, timeout=10)
+            if get_node.text == 'ok':
+                pass
+            elif get_node.text == 'error':
+                print('Central node connection: \033[0;31mError\033[0m')
+                bot_error('於中央節點的通訊失敗')
+                sys.exit()
+            else:
+                print('Central node connection: {}'.format(get_node.text))
+                bot_error('於中央節點的通訊失敗')
+                sys.exit()
+        except requests.exceptions.ConnectionError:
+            print('Central node connection: \033[0;31mError\033[0m')
+            bot_error("建立於中央節點的通訊失敗")
+            sys.exit()
+        except requests.exceptions.ReadTimeout:
+            print('Central node connection: \033[0;31mError\033[0m')
+            bot_error("於中央節點的通訊超時")
+            sys.exit()
+        except:
+            print('Central node connection: \033[0;31mError\033[0m')
+            bot_error("於中央節點的通訊失敗")
+            sys.exit()
 
-    def get_error(error_num):
+    def get_error(error_num, url_node):
                 
         print("\033[31m" + time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "\033[0m：{} | {}".format(str(error_num), node_name))
         data = {
             "chat_id":chat_id,
             "text":"{}：{}".format(node_name,str(error_num.replace(' ','%20'))),
-            "reply_markup":'{"inline_keyboard": [[{"text": "問題已解決", "callback_data": "ok"}, {"text": "忽略問題", "callback_data": "pass"}]]}'
+            "reply_markup":'{"inline_keyboard": [[{"text": "訪問該節點", "url": "{}"}, {"text": "忽略問題", "callback_data": "pass"}]]}'.format(url_node)
         }
         requests.get('https://api.telegram.org/bot{}/sendMessage'.format(bot_token), timeout=5, params=data)
         open(os.getcwd() + "/{}-sla.log".format(node_name),'a+',encoding="utf-8").write(time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：{}".format(str(error_num)+"\n"))
-        cloudlog(node_name, error_num.replace(' ','%20'))
+        cloudlog(node_name, error_num.replace(' ','%20'), url_node)
 
+    def bot_error(error_num): 
+        print("\033[31m" + time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "\033[0m：{} | {}".format(str(error_num), node_name))
+        data = {
+            "chat_id":chat_id,
+            "text":"{} (BOT)：{}".format(node_name,str(error_num.replace(' ','%20'))),
+            "reply_markup":'{"inline_keyboard": [[{"text": "忽略問題", "callback_data": "pass"}]]}'
+        }
+        requests.get('https://api.telegram.org/bot{}/sendMessage'.format(bot_token), timeout=5, params=data)
+        open(os.getcwd() + "/{}-sla.log".format(node_name),'a+',encoding="utf-8").write(time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：{}".format(str(error_num)+"\n"))
 
     try:
         miao = requests.get(url,timeout=5)
@@ -54,15 +103,15 @@ def sla(url, status, node_name, bot_token, chat_id):
             print("\033[34m" + time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "\033[0m：{} OK | {}".format(status, node_name))
             open(os.getcwd() + "/{}-sla.log".format(node_name),'a+',encoding="utf-8").write(time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：400 OK" + "\n")
         elif str(miao) == "<Response [404]>":
-            get_error("404 ERROR")
+            get_error("404 ERROR", url)
         elif str(miao) == "<Response [403]>":
-            get_error("403 ERROR")
+            get_error("403 ERROR", url)
         elif str(miao) == "<Response [503]>":
-            get_error("503 ERROR")
+            get_error("503 ERROR", url)
         elif str(miao) == "<Response [502]>":
-            get_error("502 ERROR")
+            get_error("502 ERROR", url)
         else:
-            get_error(miao)
+            get_error(miao, url)
     except:
         print("Error, repeat request")
         try:
@@ -72,18 +121,18 @@ def sla(url, status, node_name, bot_token, chat_id):
                 print("\033[34m" + time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "\033[0m：{} OK | {}".format(status, node_name))
                 open(os.getcwd() + "/{}-sla.log".format(node_name),'a+',encoding="utf-8").write(time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time())) + "：400 OK" + "\n")
             elif str(miao) == "<Response [404]>":
-                get_error("404 ERROR")
+                get_error("404 ERROR", url)
             elif str(miao) == "<Response [403]>":
-                get_error("403 ERROR")
+                get_error("403 ERROR", url)
             elif str(miao) == "<Response [503]>":
-                get_error("503 ERROR")
+                get_error("503 ERROR", url)
             elif str(miao) == "<Response [502]>":
-                get_error("502 ERROR")
+                get_error("502 ERROR", url)
             else:
-                get_error(miao)
+                get_error(miao, url)
         except requests.exceptions.ConnectionError:
-            get_error("ConnectionError")
+            get_error("ConnectionError", url)
         except requests.exceptions.ReadTimeout:
-            get_error("Timeout")
+            get_error("Timeout", url)
         except:
-            get_error("未知錯誤")
\ No newline at end of file
+            get_error("未知錯誤", url)
\ No newline at end of file
